@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
@@ -13,10 +13,10 @@
  * (1) http://ckeditor.com/builder
  *     Visit online builder to build CKEditor from scratch.
  *
- * (2) http://ckeditor.com/builder/7a359dc5bce287bc191bc7d8d9257d51
+ * (2) http://ckeditor.com/builder/efd88158c12886c4be7d99e4915df4d6
  *     Visit online builder to build CKEditor, starting with the same setup as before.
  *
- * (3) http://ckeditor.com/builder/download/7a359dc5bce287bc191bc7d8d9257d51
+ * (3) http://ckeditor.com/builder/download/efd88158c12886c4be7d99e4915df4d6
  *     Straight download link to the latest version of CKEditor (Optimized) with the same setup as before.
  *
  * NOTE:
@@ -77,8 +77,10 @@ var CKBUILDER_CONFIG = {
 		'listblock' : 1,
 		'menu' : 1,
 		'menubutton' : 1,
+		'onchange' : 1,
 		'panel' : 1,
 		'panelbutton' : 1,
+		'pastefromexcel' : 1,
 		'pastefromword' : 1,
 		'pastetext' : 1,
 		'richcombo' : 1,
@@ -120,6 +122,7 @@ var CKBUILDER_CONFIG = {
 		'ru' : 1,
 		'sk' : 1,
 		'sl' : 1,
+		'sr' : 1,
 		'sv' : 1,
 		'tr' : 1,
 		'uk' : 1,
